---
title: Querying Metrics from Prometheus
description: This task shows you how to query for Istio Metrics using Prometheus.
weight: 30
keywords: [telemetry,metrics]
---

This task shows you how to query for Istio Metrics using Prometheus. As part of
this task, you will use the web-based interface for querying metric values.

The [Bookinfo](/docs/guides/bookinfo/) sample application is used as
the example application throughout this task.

## Before you begin

[Install Istio](/docs/setup/) in your cluster and deploy an
application.

## Querying Istio Metrics

1.  Verify that the prometheus service is running in your cluster (since 0.8 the
    prometheus setup is included in istio-demo.yaml and istio-demo-auth.yaml by default)

    In Kubernetes environments, execute the following command:

    ```command
    $ kubectl -n istio-system get svc prometheus
    NAME         CLUSTER-IP     EXTERNAL-IP   PORT(S)    AGE
    prometheus   10.59.241.54   <none>        9090/TCP   2m
    ```

1.  Send traffic to the mesh.

    For the Bookinfo sample, visit `http://$GATEWAY_URL/productpage` in your web
    browser or issue the following command:

    ```command
    $ curl http://$GATEWAY_URL/productpage
    ```

    > `$GATEWAY_URL` is the value set in the [Bookinfo](/docs/guides/bookinfo/) guide.

1.  Open the Prometheus UI.

    In Kubernetes environments, execute the following command:

    ```command
    $ kubectl -n istio-system port-forward $(kubectl -n istio-system get pod -l app=prometheus -o jsonpath='{.items[0].metadata.name}') 9090:9090 &
    ```

    Visit [http://localhost:9090/graph](http://localhost:9090/graph) in your web browser.

1.  Execute a Prometheus query.

    In the "Expression" input box at the top of the web page, enter the text:
    `istio_request_count`. Then, click the **Execute** button.

The results will be similar to:

{{< image width="100%" ratio="39.36%"
    link="../img/prometheus_query_result.png"
    caption="Prometheus Query Result"
    >}}

Other queries to try:

-   Total count of all requests to `productpage` service:

    ```
    istio_request_count{destination_service="productpage.default.svc.cluster.local"}
    ```

- Total count of all requests to `v3` of the `reviews` service:

    ```
    istio_request_count{destination_service="reviews.default.svc.cluster.local", destination_version="v3"}
    ```

    This query returns the current total count of all requests to the v3 of the reviews service.

-   Rate of requests over the past 5 minutes to all `productpage` services:

    ```
    rate(istio_request_count{destination_service=~"productpage.*", response_code="200"}[5m])
    ```

### About the Prometheus add-on

Mixer comes with a built-in [Prometheus](https://prometheus.io) adapter that
exposes an endpoint serving generated metric values. The Prometheus add-on is a
Prometheus server that comes preconfigured to scrape Mixer endpoints to collect
the exposed metrics. It provides a mechanism for persistent storage and querying
of Istio metrics.

The configured Prometheus add-on scrapes three endpoints:
1. *istio-mesh* (`istio-mixer.istio-system:42422`): all Mixer-generated mesh
   metrics.
1. *mixer* (`istio-mixer.istio-system:9093`): all Mixer-specific metrics. Used
   to monitor Mixer itself.
1. *envoy* (`istio-mixer.istio-system:9102`): raw stats generated by Envoy (and
   translated from statsd to prometheus).

For more on querying Prometheus, please read their [querying
docs](https://prometheus.io/docs/querying/basics/).

## Cleanup

-   Remove any `kubectl port-forward` processes that may still be running:

    ```command
    $ killall kubectl
    ```

-   If you are not planning to explore any follow-on tasks, refer to the
    [Bookinfo cleanup](/docs/guides/bookinfo/#cleanup) instructions
    to shutdown the application.

## What's next

-   Refer to the [In-Depth Telemetry](/docs/guides/telemetry/) guide.
